generate.map: generate basic relief maps

View source: R/generate.map.R

generate.mapR Documentation

generate basic relief maps

Description

generate.map generates a ggplot map visualizing sf attributes over shaded relief. It gives you a basic map so you don't have to deal with the nitty gritty and can just focus on customizing the aesthetic.

Usage

generate.map(data, x, y, hillshade, variable, axis_degrees = TRUE)

Arguments

data

output of overlay.relief

x

name of the longitude variable in the overlay.relief output as character vector

y

name of the latitude variable in the overlay.relief output as character vector

hillshade

name of the hillshade variable in the overlay.relief output as character vector

variable

name of the variable in the overlay.relief output you wish to map as character vector

axis_degrees

if TRUE axis unit and labels will be in degrees (in accordance with the CRS of your data)

Value

ggplot object


till-tietz/rrelief documentation built on Sept. 5, 2022, 7:41 p.m.