| generate.map | R Documentation |
generate.map generates a ggplot map visualizing sf attributes over shaded relief. It gives you a basic map so you don't have to deal with the nitty gritty and can just focus on customizing the aesthetic.
generate.map(data, x, y, hillshade, variable, axis_degrees = TRUE)
data |
output of overlay.relief |
x |
name of the longitude variable in the overlay.relief output as character vector |
y |
name of the latitude variable in the overlay.relief output as character vector |
hillshade |
name of the hillshade variable in the overlay.relief output as character vector |
variable |
name of the variable in the overlay.relief output you wish to map as character vector |
axis_degrees |
if TRUE axis unit and labels will be in degrees (in accordance with the CRS of your data) |
ggplot object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.